@@ -17,10 +17,12 @@ landform_lsp_stars2 = lsp_add_stars(result_coma)
 landform_lsp_sf4 = lsp_add_sf(result_coma)
 landform_lsp_stars3 = lsp_add_stars(result_coma, metadata = FALSE)
 landform_lsp_sf5 = lsp_add_sf(result_coma, metadata = FALSE)
+result_coma2 = lsp_signature(landform, type = "cove", threshold = 1)
 
 test_that("tests lsp_add_spatial works on lsp", {
   expect_equal(length(landform_lsp_stars2), 80)
   expect_equal(length(landform_lsp_stars3), 78)
   expect_equal(ncol(landform_lsp_sf4), 4)
   expect_equal(ncol(landform_lsp_sf5), 2)
+  expect_equal(nrow(result_coma2), 1)
 })
